package com.landray.kmss.sys.attachment.service.spring;

import java.util.Comparator;
import java.util.Locale;
import java.awt.GraphicsEnvironment;
import java.util.TreeMap;
import java.util.Map;
import com.landray.kmss.web.taglib.xform.ICustomizeDataSource;

public class SysWaterMarkFontDataSource implements ICustomizeDataSource
{
    private String fdDefaultFontName;
    private Map<String, String> fontDataSource;
    
    public SysWaterMarkFontDataSource() {
        this.fdDefaultFontName = "";
        this.fontDataSource = new TreeMap<String, String>();
        final GraphicsEnvironment e = GraphicsEnvironment.getLocalGraphicsEnvironment();
        final String[] fontNames = e.getAvailableFontFamilyNames();
        final Map<String, String> tmpMap = new TreeMap<String, String>();
        final Locale locale = Locale.getDefault();
        String[] array;
        for (int length = (array = fontNames).length, i = 0; i < length; ++i) {
            final String fontName = array[i];
            if (locale.equals(Locale.CHINA) || locale.equals(Locale.CHINESE) || locale.equals(Locale.SIMPLIFIED_CHINESE)) {
                if (this.isChinese(fontName) && "".equals(this.fdDefaultFontName)) {
                    this.fdDefaultFontName = fontName;
                }
            }
            else if ((fontName.startsWith("a") || fontName.startsWith("A")) && "".equals(this.fdDefaultFontName)) {
                this.fdDefaultFontName = fontName;
            }
            tmpMap.put(fontName, fontName);
        }
        this.fontDataSource = this.sortMapByKey(tmpMap);
    }
    
    private boolean isChinese(final char c) {
        final Character.UnicodeBlock ub = Character.UnicodeBlock.of(c);
        return ub == Character.UnicodeBlock.CJK_UNIFIED_IDEOGRAPHS || ub == Character.UnicodeBlock.CJK_COMPATIBILITY_IDEOGRAPHS || ub == Character.UnicodeBlock.CJK_UNIFIED_IDEOGRAPHS_EXTENSION_A || ub == Character.UnicodeBlock.CJK_UNIFIED_IDEOGRAPHS_EXTENSION_B || ub == Character.UnicodeBlock.CJK_SYMBOLS_AND_PUNCTUATION || ub == Character.UnicodeBlock.HALFWIDTH_AND_FULLWIDTH_FORMS || ub == Character.UnicodeBlock.GENERAL_PUNCTUATION;
    }
    
    private boolean isChinese(final String strName) {
        final char[] ch = strName.toCharArray();
        for (int i = 0; i < ch.length; ++i) {
            final char c = ch[i];
            if (this.isChinese(c)) {
                return true;
            }
        }
        return false;
    }
    
    private Map<String, String> sortMapByKey(final Map<String, String> tmpMap) {
        if (tmpMap == null || tmpMap.isEmpty()) {
            return null;
        }
        final Map<String, String> sortMap = new TreeMap<String, String>(new MapKeyComparator());
        sortMap.putAll(tmpMap);
        return sortMap;
    }
    
    public Map<String, String> getOptions() {
        return this.fontDataSource;
    }
    
    public String getDefaultValue() {
        return this.fdDefaultFontName;
    }
    
    class MapKeyComparator implements Comparator<String>
    {
        @Override
        public int compare(final String str1, final String str2) {
            return str1.compareTo(str2);
        }
    }
}
